@@ -4,10 +4,10 @@
 import re
 
 import razdel
-
 from lingtrain_aligner import preprocessor
 
 RU_CODE = "ru"
+BE_CODE = "bu"
 ZH_CODE = "zh"
 DE_CODE = "de"
 EN_CODE = "en"
@@ -26,11 +26,11 @@ NL_CODE = "nl"
 SW_CODE = "sw"
 UK_CODE = "uk"
 CV_CODE = "cv"
-
 XX_CODE = "xx"
 
 LANGUAGES = {
     RU_CODE: {"name": "Russian"},
+    BE_CODE: {"name": "Belarusian"},
     ZH_CODE: {"name": "Chinese"},
     DE_CODE: {"name": "German"},
     EN_CODE: {"name": "English"},
@@ -52,6 +52,7 @@ LANGUAGES = {
     XX_CODE: {"name": "Unknown"},
 }
 
+
 # pattern_ru_orig = re.compile(r'[a-zA-Z\(\)\[\]\/\<\>•\'\n]+')
 pattern_ru_orig = re.compile(r"[\/\<\>•\'\n]+")
 double_spaces = re.compile(r"[\s]{2,}")
@@ -117,6 +118,11 @@ def after_fr(lines):
     return lines
 
 
+def after_de(lines):
+    """Some wierd German stuff"""
+    return preprocess_raw(lines, [(german_bdates, r"\1\2.\3\4")])
+
+
 def preprocess_raw(lines, re_list):
     """Preprocess raw file lines"""
     for i in range(len(lines)):
@@ -125,11 +131,12 @@ def preprocess_raw(lines, re_list):
     return lines
 
 
-def preprocess(line, re_list, splitter):
+def preprocess(line, re_list, splitter, after_fn):
     """Preprocess general line"""
     for pat, val in re_list:
         line = re.sub(pat, val, line)
-    return splitter(line)
+    splitted = splitter(line)
+    return after_fn(splitted)
 
 
 def ensure_paragraph_splitting(lines):
@@ -155,7 +162,7 @@ def get_substrings(line, sep, endings, res):
             res.append(line + sep)
 
 
-def split_by_sentences_wrapper(lines, langcode):
+def split_by_sentences_wrapper(lines, langcode, clean_text=True):
     """Special wrapper with an additional paragraph splitting"""
     res, acc = [], []
     marks = preprocessor.get_all_meta_marks()
@@ -164,7 +171,7 @@ def split_by_sentences_wrapper(lines, langcode):
             # print("found mark", line)
             if acc:
                 sentences = ensure_paragraph_splitting(
-                    split_by_sentences(acc, langcode)
+                    split_by_sentences(acc, langcode, clean_text)
                 )
                 res.extend(sentences)
                 acc = []
@@ -172,59 +179,48 @@ def split_by_sentences_wrapper(lines, langcode):
         else:
             acc.append(line)
     if acc:
-        sentences = ensure_paragraph_splitting(split_by_sentences(acc, langcode))
+        sentences = ensure_paragraph_splitting(split_by_sentences(acc, langcode, clean_text))
         res.extend(sentences)
     return res
 
 
-def split_by_sentences(lines, langcode):
+splitter_fn = {
+    JP_CODE: split_jp,
+    ZH_CODE: split_zh
+}
+
+preprocessing_rules = {
+    RU_CODE: [(pattern_ru_orig, ""), *DEFAULT_PREPROCESSING],
+    DE_CODE: [(german_quotes, '"'), (german_dates, rf"\1\2{german_foo}\3\4"), *DEFAULT_PREPROCESSING,],
+    ZH_CODE: [(pattern_zh, "")],
+    JP_CODE: [(pat_comma, "。"), (pattern_jp, "")],
+}
+
+postprocessing_rules = {
+    FR_CODE: after_fr,
+    DE_CODE: after_de
+}
+
+def split_by_sentences(lines, langcode, clean_text=True):
     """Split line by sentences using language specific rules"""
     line = " ".join(lines)
-    if langcode == RU_CODE:
-        sentences = preprocess(
-            line, [(pattern_ru_orig, ""), *DEFAULT_PREPROCESSING], split_by_razdel
-        )
-        return sentences
-    if langcode == DE_CODE:
-        sentences = preprocess(
-            line,
-            [
-                (german_quotes, '"'),
-                (german_dates, rf"\1\2{german_foo}\3\4"),
-                *DEFAULT_PREPROCESSING,
-            ],
-            split_by_razdel,
-        )
-        sentences = preprocess_raw(sentences, [(german_bdates, r"\1\2.\3\4")])
-        return sentences
-    if langcode == ZH_CODE:
-        sentences = preprocess(
-            line,
-            [
-                # (pat_comma, '。'),
-                (pattern_zh, "")
-            ],
-            split_zh,
-        )
-        return sentences
-    if langcode == JP_CODE:
-        sentences = preprocess(line, [(pat_comma, "。"), (pattern_jp, "")], split_jp)
-        return sentences
-    if langcode == FR_CODE:
-        sentences = preprocess(line, [*DEFAULT_PREPROCESSING], split_by_razdel)
-        sentences = after_fr(sentences)
-        return sentences
+    split_fn = splitter_fn.get(langcode, split_by_razdel)
+    after_fn = postprocessing_rules.get(langcode, lambda x: x)
 
-    # apply default splitting
-    sentences = preprocess(line, [*DEFAULT_PREPROCESSING], split_by_razdel)
+    if clean_text:
+        pre_rules = preprocessing_rules.get(langcode, [*DEFAULT_PREPROCESSING])
+    else:        
+        pre_rules = [*DEFAULT_PREPROCESSING]
+
+    sentences = preprocess(line, pre_rules, split_fn, after_fn)
 
     if sentences[-1].strip() == "":
-        return sentences[:-1]
+        sentences = sentences[:-1]
 
     return sentences
 
 
-def split_by_sentences_and_save(raw_path, splitted_path, langcode, handle_marks=False):
+def split_by_sentences_and_save(raw_path, splitted_path, langcode, handle_marks=False, clean_text=True):
     """Split raw text file by sentences and save"""
     with open(raw_path, mode="r", encoding="utf-8") as input_file, open(
         splitted_path, mode="w", encoding="utf-8"
@@ -234,9 +230,9 @@ def split_by_sentences_and_save(raw_path, splitted_path, langcode, handle_marks=
             lines = preprocess_raw(lines, [(quotes, '"')])
             if handle_marks:
                 lines = preprocessor.mark_paragraphs(lines)
-                sentences = split_by_sentences_wrapper(lines, langcode)
+                sentences = split_by_sentences_wrapper(lines, langcode, clean_text)
             else:
-                sentences = split_by_sentences(lines, langcode)
+                sentences = split_by_sentences(lines, langcode, clean_text)
         else:
             raise Exception("Unknown language code.")
 
